Design Principles — Pootle 2.6.1 documentation

# Design Principles

When developing Pootle we strive to achieve these principles:

1. Snappy
2. Good set of default settings
3. The most important information must be visible by default
4. Only relevant (actionable) information should be shown

Where these mean...

## Snappy

The user experience of interacting with Pootle is quick or Snappy. Essentially the user should not feel that they are waiting for Pootle.

## Good set of default settings

A default Pootle install from source should be well configured with a standard set of feature. Essoteric features should be documented but not enabled by default.

## The most important information must be visible by default

The user should not have to click anywhere to find important relevant information it should just be available.

## Only relevant (actionable) information should be shown

We show information that the user can act on. Thus we show terms that are used in the source, Translation Memory that matches the source.